@@ -6,14 +6,16 @@ import numpy as np
 from matplotlib.pyplot import cm
 
 
-def plot_lines(ax,
-               lines_loc,
-               label=None,
-               color='r',
-               line_width=0.5,
-               line_style='-',
-               line_type='vert',
-               alpha=1):
+def plot_lines(
+    ax,
+    lines_loc,
+    label=None,
+    color='r',
+    line_width=0.5,
+    line_style='-',
+    line_type='vert',
+    alpha=1,
+):
     """
     Function to draw vertical or horizontal lines on an ax
     :param ax: the matplolib axis on which to draw
@@ -45,16 +47,19 @@ def plot_lines(ax,
     if line_type == 'horiz':
         line_ = ax.axhline
     for line in lines_loc:
-        line_(line, c=color, linewidth=line_width, label=label, linestyle=line_style, alpha=alpha)
+        line_(
+            line,
+            c=color,
+            linewidth=line_width,
+            label=label,
+            linestyle=line_style,
+            alpha=alpha,
+        )
         # only the first one produce a label
         label = None
 
 
-def plot_spectro(ax,
-                 wf,
-                 chk_size=2048,
-                 noverlap=0,
-                 sr=44100):
+def plot_spectro(ax, wf, chk_size=2048, noverlap=0, sr=44100):
     """
 
     :param ax:
@@ -67,10 +72,7 @@ def plot_spectro(ax,
     ax.specgram(x=wf, NFFT=chk_size, noverlap=noverlap, Fs=sr)
 
 
-def plot_wf(ax,
-            wf,
-            wf_line_width=0.8,
-            wf_color='b'):
+def plot_wf(ax, wf, wf_line_width=0.8, wf_color='b'):
     """
 
     :param ax:
@@ -82,28 +84,30 @@ def plot_wf(ax,
     ax.plot(wf, linewidth=wf_line_width, c=wf_color)
 
 
-def plot_wf_and_spectro(wf,
-                        figsize=(40, 8),
-                        chk_size=2048,
-                        noverlap=0,
-                        sr=44100,
-                        spectra_ylim=None,
-                        wf_y_lim=None,
-                        wf_x_lim=None,
-                        spectra_xlim=None,
-                        n_sec_per_tick=None,
-                        vert_lines_samp=None,
-                        vert_lines_sec=None,
-                        vert_lines_colors=None,
-                        vert_lines_labels=None,
-                        vert_lines_width=None,
-                        vert_lines_style=None,
-                        alpha_lines=None,
-                        n_tick_dec=None,
-                        wf_line_width=1,
-                        wf_color='b',
-                        title=None,
-                        title_font_size=10):
+def plot_wf_and_spectro(
+    wf,
+    figsize=(40, 8),
+    chk_size=2048,
+    noverlap=0,
+    sr=44100,
+    spectra_ylim=None,
+    wf_y_lim=None,
+    wf_x_lim=None,
+    spectra_xlim=None,
+    n_sec_per_tick=None,
+    vert_lines_samp=None,
+    vert_lines_sec=None,
+    vert_lines_colors=None,
+    vert_lines_labels=None,
+    vert_lines_width=None,
+    vert_lines_style=None,
+    alpha_lines=None,
+    n_tick_dec=None,
+    wf_line_width=1,
+    wf_color='b',
+    title=None,
+    title_font_size=10,
+):
     """
 
     :param wf:
@@ -141,7 +145,9 @@ def plot_wf_and_spectro(wf,
 
     # getting the ticks where we want them
     ticks_pos = range(0, len(wf), int(sr * n_sec_per_tick))
-    ticks_labels = [f'{round(n_sec_per_tick * i, n_tick_dec)}s' for i in range(len(ticks_pos))]
+    ticks_labels = [
+        f'{round(n_sec_per_tick * i, n_tick_dec)}s' for i in range(len(ticks_pos))
+    ]
 
     # TODO: udnerstand wtf is going on here
     plt.sca(ax[0])
@@ -164,7 +170,9 @@ def plot_wf_and_spectro(wf,
     if vert_lines_sec is None:
         vert_lines_sec = []
     vert_lines_samp = list(vert_lines_samp)
-    vert_lines_samp += [[int(i * sr) for i in list_lines] for list_lines in vert_lines_sec]
+    vert_lines_samp += [
+        [int(i * sr) for i in list_lines] for list_lines in vert_lines_sec
+    ]
 
     for lines_idx, lines_loc in enumerate(vert_lines_samp):
 
@@ -189,14 +197,16 @@ def plot_wf_and_spectro(wf,
         else:
             vert_line_style = vert_lines_style[lines_idx]
 
-        plot_lines(ax[0],
-                   lines_loc=lines_loc,
-                   label=vert_line_label,
-                   color=vert_lines_color,
-                   line_width=vert_line_width,
-                   line_style=vert_line_style,
-                   line_type='vert',
-                   alpha=alpha_line)
+        plot_lines(
+            ax[0],
+            lines_loc=lines_loc,
+            label=vert_line_label,
+            color=vert_lines_color,
+            line_width=vert_line_width,
+            line_style=vert_line_style,
+            line_type='vert',
+            alpha=alpha_line,
+        )
         first = False
 
     # plotting the spectrogram and some limits
@@ -211,24 +221,26 @@ def plot_wf_and_spectro(wf,
     plt.show()
 
 
-def plot_wf_with_lines(wf,
-                       figsize=(40, 10),
-                       sr=44100,
-                       wf_y_lim=None,
-                       wf_x_lim=None,
-                       n_sec_per_tick=None,
-                       vert_lines_samp=None,
-                       vert_lines_sec=None,
-                       vert_lines_colors=None,
-                       vert_lines_labels=None,
-                       vert_lines_width=None,
-                       vert_lines_style=None,
-                       alpha_lines=None,
-                       n_tick_dec=None,
-                       wf_line_width=1,
-                       wf_color='b',
-                       title=None,
-                       title_font_size=10):
+def plot_wf_with_lines(
+    wf,
+    figsize=(40, 10),
+    sr=44100,
+    wf_y_lim=None,
+    wf_x_lim=None,
+    n_sec_per_tick=None,
+    vert_lines_samp=None,
+    vert_lines_sec=None,
+    vert_lines_colors=None,
+    vert_lines_labels=None,
+    vert_lines_width=None,
+    vert_lines_style=None,
+    alpha_lines=None,
+    n_tick_dec=None,
+    wf_line_width=1,
+    wf_color='b',
+    title=None,
+    title_font_size=10,
+):
     """
     :param wf:
     :param figsize:
@@ -261,7 +273,9 @@ def plot_wf_with_lines(wf,
 
     # getting the ticks where we want them
     ticks_pos = range(0, len(wf), int(sr * n_sec_per_tick))
-    ticks_labels = [f'{round(n_sec_per_tick * i, n_tick_dec)}s' for i in range(len(ticks_pos))]
+    ticks_labels = [
+        f'{round(n_sec_per_tick * i, n_tick_dec)}s' for i in range(len(ticks_pos))
+    ]
 
     # TODO: udnerstand wtf is going on here
     plt.sca(ax)
@@ -284,7 +298,9 @@ def plot_wf_with_lines(wf,
     if vert_lines_sec is None:
         vert_lines_sec = []
     vert_lines_samp = list(vert_lines_samp)
-    vert_lines_samp += [[int(i * sr) for i in list_lines] for list_lines in vert_lines_sec]
+    vert_lines_samp += [
+        [int(i * sr) for i in list_lines] for list_lines in vert_lines_sec
+    ]
 
     for lines_idx, lines_loc in enumerate(vert_lines_samp):
 
@@ -309,14 +325,16 @@ def plot_wf_with_lines(wf,
         else:
             vert_line_style = vert_lines_style[lines_idx]
 
-        plot_lines(ax,
-                   lines_loc=lines_loc,
-                   label=vert_line_label,
-                   color=vert_lines_color,
-                   line_width=vert_line_width,
-                   line_style=vert_line_style,
-                   line_type='vert',
-                   alpha=alpha_line)
+        plot_lines(
+            ax,
+            lines_loc=lines_loc,
+            label=vert_line_label,
+            color=vert_lines_color,
+            line_width=vert_line_width,
+            line_style=vert_line_style,
+            line_type='vert',
+            alpha=alpha_line,
+        )
 
     fig.suptitle(title, fontsize=title_font_size)
     plt.legend(loc=(1.04, 0.8))
