@@ -1,4 +1,24 @@
-"""Function to reduce and plot data in 2 or 3 dimensions"""
+"""
+Function to reduce and plot data in 2 or 3 dimensions
+
+Example of usage:
+
+from sklearn.datasets import make_blobs
+
+X, y = make_blobs(n_samples=300, n_features=4, centers=3, cluster_std=1.0)
+
+y_conf = []
+for i in range(len(y)):
+    if y[i] == 0 or y[i] == 2:
+        y_conf.append(0)
+    else:
+        y_conf.append(1)
+y_conf = np.array(y_conf)
+
+scatter_and_color_according_to_y(X, y_conf, col='rainbow', dim_reduct='LDA', projection='3d')
+
+
+"""
 
 import numpy as np
 import matplotlib.pyplot as plt
@@ -15,12 +35,22 @@ import matplotlib.patches as mpatches
 import matplotlib
 
 
-def scatter_and_color_according_to_y(X, y=None, col='rainbow', projection='2d', dim_reduct='LDA',
-                                     save=False, legend=True,
-                                     saving_loc='/home/chris/', saving_name='myplot-', plot_tag_name=False,
-                                     super_alpha=10,
-                                     cmap_col='viridis',
-                                     *args, **kwargs):
+def scatter_and_color_according_to_y(
+    X,
+    y=None,
+    col='rainbow',
+    projection='2d',
+    dim_reduct='LDA',
+    save=False,
+    legend=True,
+    saving_loc='/home/chris/',
+    saving_name='myplot-',
+    plot_tag_name=False,
+    super_alpha=10,
+    cmap_col='viridis',
+    *args,
+    **kwargs
+):
     """
     :param X: an array of feature vectors
     :param y: an array of tags
@@ -50,8 +80,10 @@ def scatter_and_color_according_to_y(X, y=None, col='rainbow', projection='2d',
     elif projection == '3d':
         proj_dim = 3
     else:
-        warnings.warn('The choices for the parameter projectionare'
-                      ' \'1d\', \'2d\' or \'3d\'. Anything else and it will be assumed to be \'2d\' by default')
+        warnings.warn(
+            'The choices for the parameter projectionare'
+            " '1d', '2d' or '3d'. Anything else and it will be assumed to be '2d' by default"
+        )
         proj_dim = 2
 
     if y is None:
@@ -60,7 +92,9 @@ def scatter_and_color_according_to_y(X, y=None, col='rainbow', projection='2d',
         n_tags = 1
         tags = [0]
         if dim_reduct == 'LDA':
-            warnings.warn('LDA cannot be used if no y is provided, will use PCA instead')
+            warnings.warn(
+                'LDA cannot be used if no y is provided, will use PCA instead'
+            )
             dim_reduct = 'PCA'
 
     elif isinstance(y[0], float):
@@ -70,16 +104,20 @@ def scatter_and_color_according_to_y(X, y=None, col='rainbow', projection='2d',
         col = 'continuous'
         no_tag = True
         if dim_reduct == 'LDA':
-            warnings.warn('LDA cannot be used if the y entries are floats, will use PCA instead')
+            warnings.warn(
+                'LDA cannot be used if the y entries are floats, will use PCA instead'
+            )
             dim_reduct = 'PCA'
 
     else:
         tags = np.unique(y)
         n_tags = len(tags)
-        if dim_reduct=='LDA' and proj_dim > n_tags - 1:
-                warnings.warn('LDA cannot be used to produce {} dimensions if y has less than {} classes,'
-                              ' will use PCA instead'.format(proj_dim, proj_dim+1))
-                dim_reduct = 'PCA'
+        if dim_reduct == 'LDA' and proj_dim > n_tags - 1:
+            warnings.warn(
+                'LDA cannot be used to produce {} dimensions if y has less than {} classes,'
+                ' will use PCA instead'.format(proj_dim, proj_dim + 1)
+            )
+            dim_reduct = 'PCA'
 
     second_index = 1
     third_index = 2
@@ -118,12 +156,23 @@ def scatter_and_color_according_to_y(X, y=None, col='rainbow', projection='2d',
             second_index = 0
         if colors is not None:
             for c, i in zip(colors, tags):
-                sc = ax.scatter(X[y == i, 0], np.zeros(np.sum(y == i)), c=[c], alpha=alpha,
-                                 s=10, linewidths=0.05, marker='+', *args, **kwargs)
+                sc = ax.scatter(
+                    X[y == i, 0],
+                    np.zeros(np.sum(y == i)),
+                    c=[c],
+                    alpha=alpha,
+                    s=10,
+                    linewidths=0.05,
+                    marker='+',
+                    *args,
+                    **kwargs
+                )
                 if legend:
                     handle = mpatches.Patch(color=c, label=i)
                     handles.append(handle)
-                    ax.legend(handles=handles, loc='center left', bbox_to_anchor=(1, 0.5))
+                    ax.legend(
+                        handles=handles, loc='center left', bbox_to_anchor=(1, 0.5)
+                    )
         else:
             ax.scatter(X[:, 0], X[:, second_index], c=y, alpha=alpha, *args, **kwargs)
             ax.colorbar()
@@ -136,11 +185,20 @@ def scatter_and_color_according_to_y(X, y=None, col='rainbow', projection='2d',
             second_index = 0
         if colors is not None:
             for c, i in zip(colors, tags):
-                sc = ax.scatter(X[y == i, 0], X[y == i, second_index], c=[c], alpha=alpha, *args, **kwargs)
+                sc = ax.scatter(
+                    X[y == i, 0],
+                    X[y == i, second_index],
+                    c=[c],
+                    alpha=alpha,
+                    *args,
+                    **kwargs
+                )
                 if legend:
                     handle = mpatches.Patch(color=c, label=i)
                     handles.append(handle)
-                    ax.legend(handles=handles, loc='center left', bbox_to_anchor=(1, 0.5))
+                    ax.legend(
+                        handles=handles, loc='center left', bbox_to_anchor=(1, 0.5)
+                    )
         else:
             ax.scatter(X[:, 0], X[:, second_index], c=y, alpha=alpha, *args, **kwargs)
             ax.colorbar()
@@ -156,13 +214,29 @@ def scatter_and_color_according_to_y(X, y=None, col='rainbow', projection='2d',
         ax = fig.add_subplot(111, projection='3d')
         if colors is not None:
             for c, i in zip(colors, tags):
-                sc = ax.scatter(X[y == i, 0],  X[y == i, second_index], X[y == i, third_index], c=[c], alpha=alpha)
+                sc = ax.scatter(
+                    X[y == i, 0],
+                    X[y == i, second_index],
+                    X[y == i, third_index],
+                    c=[c],
+                    alpha=alpha,
+                )
                 if legend:
                     handle = mpatches.Patch(color=c, label=i)
                     handles.append(handle)
-                    ax.legend(handles=handles, loc='center left', bbox_to_anchor=(1, 0.5))
+                    ax.legend(
+                        handles=handles, loc='center left', bbox_to_anchor=(1, 0.5)
+                    )
         else:
-            p = ax.scatter(X[:, 0], X[:, second_index], X[:, third_index], c=y, alpha=alpha, *args, **kwargs)
+            p = ax.scatter(
+                X[:, 0],
+                X[:, second_index],
+                X[:, third_index],
+                c=y,
+                alpha=alpha,
+                *args,
+                **kwargs
+            )
             fig.colorbar(p)
 
     if plot_tag_name and not no_tag:
@@ -171,11 +245,20 @@ def scatter_and_color_according_to_y(X, y=None, col='rainbow', projection='2d',
             if projection == '2d':
                 plt.text(tag_center[0], tag_center[1], tags[tag])
             else:
-                ax.text(tag_center[0], tag_center[1], tag_center[2], tags[tag], size=20, zorder=1,
-                        color='k')
+                ax.text(
+                    tag_center[0],
+                    tag_center[1],
+                    tag_center[2],
+                    tags[tag],
+                    size=20,
+                    zorder=1,
+                    color='k',
+                )
 
     if save:
-        path = saving_loc + saving_name + datetime.datetime.today().strftime('%Y-%m-%d-%r')
+        path = (
+            saving_loc + saving_name + datetime.datetime.today().strftime('%Y-%m-%d-%r')
+        )
         plt.savefig(path, bbox_inches='tight')
     plt.show()
 
@@ -204,8 +287,9 @@ def save_figs_to_pdf(figs, pdf_filepath=None):
 #     return r/255, g/255, b/255, 1
 
 
-
-def side_by_side_bar(list_of_values_for_bars, width=1, spacing=1, list_names=None, colors=None):
+def side_by_side_bar(
+    list_of_values_for_bars, width=1, spacing=1, list_names=None, colors=None
+):
     """
     A plotting utility making side by side bar graphs from a list of list (of same length) of values.
 
@@ -225,47 +309,21 @@ def side_by_side_bar(list_of_values_for_bars, width=1, spacing=1, list_names=Non
     if colors is None:
         colors = plt.cm.rainbow(np.linspace(0, 1, n_bars))
     else:
-        assert len(colors) >= n_bars, "There's not enough colors for the number of bars ({})".format(n_bars)
+        assert (
+            len(colors) >= n_bars
+        ), "There's not enough colors for the number of bars ({})".format(n_bars)
     ax = plt.subplot(111)
     # making each of the bar plot
     for i, list_of_values_for_bars in enumerate(list_of_values_for_bars):
-        x = [width * j * n_bars + spacing * j + i * width for j in range(len(list_of_values_for_bars))]
+        x = [
+            width * j * n_bars + spacing * j + i * width
+            for j in range(len(list_of_values_for_bars))
+        ]
         ax.bar(x, list_of_values_for_bars, width=width, color=colors[i], align='center')
     ax.legend(list_names)
     ax.xaxis.set_ticklabels([])
 
 
-# def comparison_vlines(y1, y2, c1='b', c2='r'):
-#     """
-#
-#     :param y1:
-#     :param y2:
-#     :param c1:
-#     :param c2:
-#     :return:
-#     """
-#     n = len(y1)
-#     assert len(y2) == n, "y1 and y2 need to be of the same length"
-#     plt.vlines(list(range(n)), y1, y2)
-#     plt.plot(y1, 'o', color=c1)
-#     plt.plot(y2, 'o', color=c2)
-#
-#
-# def diff_comparison_vlines(y1, y2, c1='b', c2='k'):
-#     """
-#
-#     :param y1:
-#     :param y2:
-#     :param c1:
-#     :param c2:
-#     :return: what plt.plot returns
-#     """
-#     y = np.array(y1) - np.array(y2)
-#     plt.vlines(list(range(len(y))), 0, y)
-#     plt.hlines(0, 0, len(y) - 1, colors=c2)
-#     return plt.plot(list(range(len(y))), y, 'o', color=c1)
-
-
 def ratio_comparison_vlines(y1, y2, c1='b', c2='k'):
     """
     Plots vlines of y1/y2.
@@ -279,19 +337,3 @@ def ratio_comparison_vlines(y1, y2, c1='b', c2='k'):
     plt.vlines(list(range(len(y))), 1, y)
     plt.hlines(1, 0, len(y) - 1, colors=c2)
     return plt.plot(list(range(len(y))), y, 'o', color=c1)
-
-
-# if __name__ == '__main__':
-#
-#     from sklearn.datasets import make_blobs
-#     X, y = make_blobs(n_samples=300, n_features=4, centers=1, cluster_std=1.0)
-#
-#     # y_conf = []
-#     # for i in range(len(y)):
-#     #     if y[i] == 0 or y[i] == 2:
-#     #         y_conf.append(0)
-#     #     else:
-#     #         y_conf.append(1)
-#     # y_conf = np.array(y_conf)
-#
-#     scatter_and_color_according_to_y(X, y, col='rainbow', dim_reduct='LDA', projection='3d')
